<?php defined('MW_PATH') || exit('No direct script access allowed');


/**
 * Controller file for HoopoEmail.com settings.
 *
 * @package hoopoemail.com
 * @link https://www.hoopoemail.com/
 * @license https://www.hoopoemail.com/license/
 */

class Ext_mw_hoopoemail_testServerController extends Controller
{
    // the extension instance
    public $extension;

    public $api_url = 'https://app.hoopoemail.com/api/';

    public function getViewPath()
    {
        return Yii::getPathOfAlias('ext-mw-hoopoemail.backend.views.test-server');
    }
    public function actionWarmup()
    {
        $request = app()->request;
        if ($request->isPostRequest) {
            $campaign_uid = (string)$request->getPost('campaign_uid');
            $campaign = Campaign::model()->findByUid($campaign_uid);
            if($campaign) {
                $content = $campaign->template->content;
                $sendAt = $campaign->dateTimeFormatter->formatDateTime($campaign->send_at);
                if(!empty($content)) {
                    $api_key = $this->extension->getOption('api_key');
                    $curl = curl_init();
                    curl_setopt_array($curl, array(
                        CURLOPT_URL => $this->api_url . 'warmup-campaigns',
                        CURLOPT_RETURNTRANSFER => true,
                        CURLOPT_MAXREDIRS => 10,
                        CURLOPT_TIMEOUT => 30,
                        CURLOPT_CUSTOMREQUEST => "POST",
                        CURLOPT_POSTFIELDS => [
                            'warm_up_campaign' => $content,
                            'send_at' => $sendAt,
                            'status' => 'active',
                        ],
                        CURLOPT_HTTPHEADER => array(
                            "authorization: Bearer $api_key",
                            "content-type: multipart/form-data",
                        ),
                    ));
                    $response = json_decode(curl_exec($curl));
                    $err = curl_error($curl);
                    curl_close($curl);
                    if ($err || false === $response->success) {
                        $redirect = ['campaigns/confirm', 'campaign_uid' => $campaign->campaign_uid];
                        notify()->addError('Plz try again later');
                        $this->redirect($redirect);
                    } else {
                        $redirect = ['campaigns/confirm', 'campaign_uid' => $campaign->campaign_uid];
                        notify()->addSuccess('Campaign warm-up with campaign uid '.$response->data->campaign_uid. ' had been requested. to check the warm-up detail see the hoopoemail.com');
                        $this->redirect($redirect);
                    }
                }
            }
        }
    }
    public function actionTest()
    {
        $request = app()->request;
        if ($request->isPostRequest) {
            $api_key = $this->extension->getOption('api_key');
            unset(app()->request->cookies['inbox_rate_of_campaign_uid']);
            $server_id = (int)$request->getPost('inbox_server_id');
            $deliveryServer = DeliveryServer::model()->findByPk($server_id);
            if($deliveryServer && $api_key) {
                $curl = curl_init();
                $username = !empty($deliveryServer->username) ? $deliveryServer->username : 'example';
                $from_email = !empty($deliveryServer->from_email) ? $deliveryServer->from_email : 'example@example.com';
                $from_name = !empty($deliveryServer->from_name) ? $deliveryServer->from_name : 'example';
                $reply_to_email = !empty($deliveryServer->reply_to_email) ? $deliveryServer->reply_to_email : 'example@example.com';
                curl_setopt_array($curl, array(
                    CURLOPT_URL => $this->api_url . 'test-with-create',
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_MAXREDIRS => 10,
                    CURLOPT_TIMEOUT => 30,
                    CURLOPT_CUSTOMREQUEST => "POST",
                    CURLOPT_POSTFIELDS => [
                        'name' => $deliveryServer->name,
                        'type' => $deliveryServer->type,
                        'hostname' => $deliveryServer->hostname,
                        'username' => $username,
                        'port' => $deliveryServer->port,
                        'protocol' => $deliveryServer->protocol,
                        'password' => $deliveryServer->password,
                        'timeout' => $deliveryServer->timeout ?? 30,
                        'from_email' => $from_email,
                        'from_name' => $from_name,
                        'reply_to_email' => $reply_to_email,
                        'status' => 'active',
                    ],
                    CURLOPT_HTTPHEADER => array(
                        "authorization: Bearer $api_key",
                        "content-type: multipart/form-data",
                    ),
                ));
                $response = json_decode(curl_exec($curl));
                $err = curl_error($curl);
                curl_close($curl);
                if ($err || false === $response->success) {
                    $cookie = new CHttpCookie('inbox_rate_of_campaign_uid', $response->data['campaign_uid']);
                    $cookie->expire = time()+360*24*3600;
                    app()->request->cookies['inbox_rate_of_campaign_uid'] = $cookie;
                    $redirect = ['delivery_servers/update', 'type' => $deliveryServer->type, 'id' => $deliveryServer->server_id];
                    notify()->addError($response->message);
                    $this->redirect($redirect);
                } else {
                    $redirect = ['delivery_servers/update', 'type' => $deliveryServer->type, 'id' => $deliveryServer->server_id];
                    notify()->addSuccess($response->message);
                    $this->redirect($redirect);
                }
            }
            $redirect = ['delivery_servers/update', 'type' => $deliveryServer->type, 'id' => $deliveryServer->server_id];
            notify()->addError('HoopoEmail api key is not set');
            $this->redirect($redirect);
        }
        $this->setData(array(
            'pageMetaTitle'    => $this->data->pageMetaTitle . ' | '. Yii::t('ext_mw_hoopoemail', 'HoopoEmail.com'),
            'pageHeading'      => Yii::t('ext_mw_hoopoemail', 'HoopoEmail.com'),
            'pageBreadcrumbs'  => array(
                Yii::t('app', 'Extensions') => $this->createUrl('extensions/index'),
                Yii::t('ext_mw_hoopoemail', 'HoopoEmail.com') => $this->createUrl('ext_mw_hoopoemail_settings/index'),
            )
        ));

        $this->render('index', compact('model'));
    }
    public function actionResult()
    {
        if(app()->request->isAjaxRequest) {
            $api_key = $this->extension->getOption('api_key');
            $curl = curl_init();
            $campaign_uid = (string) app()->request->cookies['inbox_rate_of_campaign_uid']->value;
            if(!empty($campaign_uid)) {
                curl_setopt_array($curl, array(
                    CURLOPT_URL => $this->api_url.'campaigns/report/'.$campaign_uid,
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_ENCODING => "",
                    CURLOPT_MAXREDIRS => 10,
                    CURLOPT_TIMEOUT => 30,
                    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                    CURLOPT_CUSTOMREQUEST => "GET",
                    CURLOPT_HTTPHEADER => array(
                        "authorization: Bearer $api_key",
                    ),
                ));

                $response = json_decode(curl_exec($curl),true);
                $err = curl_error($curl);

                curl_close($curl);
                if (isset($response['success']) && isset($response['data'])) {
                    $report = $response['data'][0];
                    $this->renderJson([
                        'data' => $report,
                        'status'  => 'success',
                        'message' => 'Loaded',
                    ]);
                }else {
                    $this->renderJson([
                        'status'  => 'fail',
                        'message' => 'Problem happened',
                    ]);
                }
            }
            $this->renderJson([
                'status'  => 'fail',
                'message' => 'Problem happened',
            ]);
        }
    }
    public function actionCheck()
    {
        if(app()->request->isAjaxRequest) {
            $api_key = $this->extension->getOption('api_key');
            $curl = curl_init();
            $inbox_email = (string) app()->request->cookies['test_email_check']->value;
            if(!empty($inbox_email)) {
                curl_setopt_array($curl, array(
                    CURLOPT_URL => $this->api_url.'mailtester?inbox_email='.$inbox_email,
                    CURLOPT_RETURNTRANSFER => true,
                    CURLOPT_ENCODING => "",
                    CURLOPT_MAXREDIRS => 10,
                    CURLOPT_TIMEOUT => 30,
                    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                    CURLOPT_CUSTOMREQUEST => "GET",
                    CURLOPT_HTTPHEADER => array(
                        "authorization: Bearer $api_key",
                    ),
                ));

                $response = json_decode(curl_exec($curl),true);
                $err = curl_error($curl);

                curl_close($curl);
                if (isset($response['success']) && isset($response['data'])) {
                    $report = $response['data'];
                    $this->renderJson([
                        'data' => $report,
                        'status'  => 'success',
                        'message' => 'Loaded',
                    ]);
                }else {
                    $this->renderJson([
                        'status'  => 'fail',
                        'message' => 'Problem happened',
                    ]);
                }
            }
            $this->renderJson([
                'status'  => 'fail',
                'message' => 'Problem happened',
            ]);
        }
    }
    public function actionIndex()
    {
        $request = app()->request;
        if ($request->isPostRequest) {
            unset(Yii::app()->request->cookies['test_email_check']);
            $server_id = (int)$request->getPost('server_id');
            $server = DeliveryServer::model()->findByPk($server_id);
            $email = 'test-' . app()->getSecurityManager()->generateRandomString(12,true).'@'.'hoopoemail.com';

            $params = CommonEmailTemplate::getAsParamsArrayBySlug(
                'delivery-server-validation',
                [
                    'to' => $email,
                    'subject' => t('servers', 'Please validate this server.'),
                ],
                [
                    '[HOSTNAME]' => $server->hostname,
                    '[CONFIRMATION_URL]' => createAbsoluteUrl('delivery_servers/confirm', ['key' => $server->confirmation_key]),
                    '[CONFIRMATION_KEY]' => $server->confirmation_key,
                ]
            );
            if (!is_null($server) && $server->sendEmail($params)) {
                $cookie = new CHttpCookie('test_email_check', $email);
                $cookie->expire = time()+360*24*3600;
                app()->request->cookies['test_email_check'] = $cookie;
                $redirect = ['delivery_servers/update', 'type' => $server->type, 'id' => $server->server_id];
                notify()->addSuccess('Successfully sent, please wait until result is ready then click on check button');
                $this->redirect($redirect);
            }else {
                $redirect = ['delivery_servers/update', 'type' => $server->type, 'id' => $server->server_id];
                notify()->addError('Can not send email through this server');
                $this->redirect($redirect);
            }
        }
        $this->setData(array(
            'pageMetaTitle'    => $this->data->pageMetaTitle . ' | '. Yii::t('ext_mw_hoopoemail', 'HoopoEmail.com'),
            'pageHeading'      => Yii::t('ext_mw_hoopoemail', 'HoopoEmail.com'),
            'pageBreadcrumbs'  => array(
                Yii::t('app', 'Extensions') => $this->createUrl('extensions/index'),
                Yii::t('ext_mw_hoopoemail', 'HoopoEmail.com') => $this->createUrl('ext_mw_hoopoemail_settings/index'),
            )
        ));

        $this->render('index', compact('model'));
    }
}
