<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * HoopoEmailExt Model
 *
 * @package hoopoemail.com
 * @link https://www.hoopoemail.com/
 * @license https://www.hoopoemail.com/license/
 */

class MwHoopoemailExtCommon extends FormModel
{
    public $enabled = 'no';

    public $api_url = 'https://app.hoopoemail.com/api/';

    public $api_key = '';

    public $warmup_requests = array();

    public function rules()
    {
        $rules = array(
            array('api_key, warmup_requests', 'safe'),
            array('enabled', 'in', 'range' => array_keys($this->getYesNoOptions())),
        );
        return CMap::mergeArray($rules, parent::rules());
    }

    public function attributeLabels()
    {
        $extension = $this->getExtensionInstance();
        $labels = array(
            'enabled'          => Yii::t('app', 'Enabled'),
            'api_key'          => $extension->t('Api key'),
            'warmup_requests'  => $extension->t('Warm-up request'),
            'hoopoemail_user_mail'  => $extension->t('User Email'),
        );
        return CMap::mergeArray($labels, parent::attributeLabels());
    }

    public function attributePlaceholders()
    {
        $placeholders = array(
            'api_key' => '',
        );
        return CMap::mergeArray($placeholders, parent::attributePlaceholders());
    }

    public function attributeHelpTexts()
    {
        $extension = $this->getExtensionInstance();
        $texts = array(
            'enabled'           => Yii::t('app', 'Whether the feature is enabled'),
            'api_key'           => $extension->t('The api key for the service. To get api key check app.hoopoemail.com/account/tokens'),
            'warmup_requests'   => $extension->t('Select delivery servers that you need warm-up. If you want to check warm-up process, take a look at hoopoemail.com'),
        );
        return CMap::mergeArray($texts, parent::attributeHelpTexts());
    }

    public function save()
    {
        $extension  = $this->getExtensionInstance();
        $attributes = array('enabled', 'api_key','warmup_requests');
        $curl = curl_init();
        curl_setopt_array($curl, array(
            CURLOPT_URL => $this->api_url.'user-details',
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 30,
            CURLOPT_CUSTOMREQUEST => "GET",
            CURLOPT_HTTPHEADER => array(
                "authorization: Bearer $this->api_key",
            ),
        ));

        $response = json_decode(curl_exec($curl));
        $err = curl_error($curl);

        curl_close($curl);
        if ($err || !isset($response->success) || false === $response->success) {
            $this->addError('api_key', $err ?? 'Api key is not correct');
        }
        $serverId = array_filter(array_map('intval', array_map('trim', (array)$this->warmup_requests)));
        $deliveryServer = DeliveryServer::model()->findByPk($serverId);
        if(!is_null($deliveryServer)) {
            $curl = curl_init();
            $username = !empty($deliveryServer->username) ? $deliveryServer->username : 'example';
            $from_email = !empty($deliveryServer->from_email) ? $deliveryServer->from_email : 'example@example.com';
            $from_name = !empty($deliveryServer->from_name) ? $deliveryServer->from_name : 'example';
            $reply_to_email = !empty($deliveryServer->reply_to_email) ? $deliveryServer->reply_to_email : 'example@example.com';
            curl_setopt_array($curl, array(
                CURLOPT_URL => $this->api_url.'public-warmup-request',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 30,
                CURLOPT_CUSTOMREQUEST => "POST",
                CURLOPT_POSTFIELDS => [
                    'name' => $deliveryServer->name,
                    'type' => $deliveryServer->type,
                    'hostname' => $deliveryServer->hostname,
                    'username' => $username,
                    'port' => $deliveryServer->port,
                    'protocol' => $deliveryServer->protocol,
                    'password' => $deliveryServer->password,
                    'timeout' => $deliveryServer->timeout ?? 30,
                    'from_email' => $from_email,
                    'from_name' => $from_name,
                    'reply_to_email' => $reply_to_email,
                    'status' => 'active',
                ],
                CURLOPT_HTTPHEADER => array(
                    "authorization: Bearer $this->api_key",
                    "content-type: multipart/form-data",
                ),
            ));
            $response = json_decode(curl_exec($curl));
            $err = curl_error($curl);
            curl_close($curl);
            if ($err || false === $response->success ) {
                foreach ($attributes as $name) {
                    $extension->setOption($this->getOptionKeyPrefix() . $name, $this->$name);
                }
                $this->addError('warmup_requests',$response->message ??  $err ?? 'Try again later');
                return false;
            } else {
                foreach ($attributes as $name) {
                    $extension->setOption($this->getOptionKeyPrefix() . $name, $this->$name);
                }
                $extension->setOption($this->getOptionKeyPrefix() . 'warmup_requests', array_filter(array_map('intval', array_map('trim', (array)$this->warmup_requests))));
                return $this;
            }
        }else {
            foreach ($attributes as $name) {
                $extension->setOption($this->getOptionKeyPrefix() . $name, $this->$name);
            }
        }
        return $this;
    }

    public function populate()
    {
        $extension  = $this->getExtensionInstance();
        $attributes = array('enabled', 'api_key','warmup_requests');
        foreach ($attributes as $name) {
            $this->$name = $extension->getOption($this->getOptionKeyPrefix() . $name, $this->$name);
        }
        return $this;
    }

    public function getOptionKeyPrefix()
    {
        return '';
    }

    public function getDeliveryServersList(): array
    {
        $deliveryServers = DeliveryServer::model()->findAll();
        $list = array();

        foreach ($deliveryServers as $deliveryServer) {
            $list[$deliveryServer->server_id] = $deliveryServer->name;
        }

        return $list;
    }
    public function getExtensionInstance()
    {
        return Yii::app()->extensionsManager->getExtensionInstance('mw-hoopoemail');
    }
}
