<?php declare(strict_types=1);
defined('MW_PATH') or exit('No direct script access allowed');

/**
 * HoopoEmailExt Model
 *
 * @package hoopoemail.com
 * @link https://www.hoopoemail.com/
 * @license https://www.hoopoemail.com/license/
 */
/** @var Controller $controller */
$controller = controller();

/** @var DeliveryServer $server */
$server = $controller->getData('server');

?>

<?php
if (!$server->getIsNewRecord() && ($server->status === DeliveryServer::STATUS_INACTIVE) && ($server->type === DeliveryServer::TRANSPORT_SMTP)) {
    /** @var CActiveForm $form */
    $form = $controller->beginWidget('CActiveForm', [
        'action'    => createUrl('ext_mw_hoopoemail_test_server/index'),
    ]); ?>
    <div class="box box-primary borderless">
        <div class="box-header">
            <h3 class="box-title">
                <?php echo CHtml::link(IconHelper::make('info'), '#test-server', ['class' => 'btn btn-primary btn-xs btn-flat', 'title' => t('app', 'Info'), 'data-toggle' => 'modal']); ?>
                <?php echo 'Test this server'; ?>
                <?php echo CHtml::hiddenField('server_id',$server->server_id); ?>
            </h3>
        </div>
        <div class="box-body">
            <p>
                Before sending emails using this server, make sure all of your mail settings(Dkim, Spf , Ip status and your delivery system reputation) is correct via hoopoemail.com
            </p>
        </div>
        <div class="box-footer">
            <div class="pull-right">
                <button type="submit" class="btn btn-primary btn-flat"><?php echo IconHelper::make('fa-send') . '&nbsp;' . t('servers', 'Test server'); ?></button>
                <?php
                if($email = app()->request->cookies['test_email_check'] ?? false) {
                    echo CHtml::htmlButton(IconHelper::make('fa-check') . '&nbsp;' . 'Check Result', ['id' => 'check-result', 'class' => 'btn btn-primary btn-flat']);
                }
                ?>
            </div>
            <div class="clearfix"><!-- --></div>
        </div>
        <div id="result" style="display: none;">

        </div>
    </div>
    <?php $controller->endWidget(); ?>
    <hr />
    <!-- modals -->
    <div class="modal modal-info fade" id="test-server" tabindex="-1" role="dialog">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                    <h4 class="modal-title"><?php echo IconHelper::make('info') . t('app', 'Info'); ?></h4>
                </div>
                <div class="modal-body">
                    <p>
                        Before sending emails using this server, make sure all of your mail settings(Dkim, Spf , Ip status and your delivery system reputation) is correct via hoopoemail.com.
           Please register in the HoopoeMail app. when you register you can create api key and start your testing email system
                </div>
            </div>
        </div>
    </div>
    <?php
} ?>
<script>
    jQuery(document).ready(function($) {
        if ($('meta[name=csrf-token-name]').length && $('meta[name=csrf-token-value]').length) {
            var csrfTokenName = $('meta[name=csrf-token-name]').attr('content');
            var csrfTokenValue = $('meta[name=csrf-token-value]').attr('content');
            ajaxData[csrfTokenName] = csrfTokenValue;
        }
        $(document).on('click', '#check-result', function(){
            ajaxData['email'] = '<?= CHtml::encode($email); ?>';
            $.post('<?= createAbsoluteUrl('ext_mw_hoopoemail_test_server/check') ?>', ajaxData, function(result){
                if(result.status === 'success') {
                    let spfRecords = result.data.spf_status;
                    let dkimRecords = result.data.dkim_status;
                    let senderIpStatus = result.data.sender_ip_status;
                    let check_result = $('#result');
                    check_result.css('display', 'block')
                    check_result.empty();
                    check_result.append(
                        '<div class="panel spf-record-panel"></div>'
                    );
                    $('.spf-record-panel').append(`
                        <div class="panel-heading spf-record-panel--heading">Spf Status: ${spfRecords.status}</div>
                    `)
                    if(spfRecords.status === 'Pass') {
                        $('.spf-record-panel').addClass('panel-success');
                    }else {
                        $('.spf-record-panel').addClass('panel-danger');
                    }
                    if(spfRecords.reasons !== undefined && spfRecords.reasons !== null && spfRecords.reasons.length > 0) {
                        $('.spf-record-panel').append(`
                          <div class="panel-body spf-record-panel--body"">
                          </div>
                        `)
                        $('.spf-record-panel--body').append('<ul></ul>')
                        spfRecords.reasons.forEach
                        (reason => {
                            $('.spf-record-panel--body').append(`
                                <li>${reason}</li>
                            `)
                        })
                    }

                    if(dkimRecords !== undefined) {
                        check_result.append(
                            '<div class="panel dkim-record-panel panel-default"></div>'
                        );
                        $('.dkim-record-panel').append(`
                        <div class="panel-heading dkim-record-panel--heading">Dkim</div>
                    `)
                        $('.dkim-record-panel').append(`
                          <div class="panel-body dkim-record-panel--body"">
                          </div>
                        `)
                        $('.dkim-record-panel--body').append(`<table class="table table-bordered">
                            <thead>
                            <th>Reason</th>
                            <th>Status</th>
                            </thead>
                            <tbody id="dkim-tbody">
                            </tbody>
</table>`)
                        dkimRecords.reasons.forEach
                            (r => { r.forEach((v) => {
                                $('#dkim-tbody').append(`
                                    <tr>
                                        <td>${v.reason}</td>
                                        <td>${v.status}</td>
                                    </tr>
                                `);
                            })
                        })
                    }
                    if(senderIpStatus !== undefined) {
                        check_result.append(
                            '<div class="panel sender-record-panel" style="border-top-width: 0;"></div>'
                        );
                        $('.sender-record-panel').append(`
                        <div class="panel-heading sender-record-panel--heading">
${senderIp(senderIpStatus)}
</div>
                    `)
                        console.log(senderIpStatus)
                        if(senderIpStatus.reason !== undefined && senderIpStatus.reason.length > 0) {
                            $('.sender-record-panel').append(`
                          <div class="panel-body sender-record-panel--body">
                          </div>
                        `)
                            $('.sender-record-panel--body').append('<ul></ul>')
                            senderIpStatus.reason.forEach
                            (r => {
                                $('.sender-record-panel--body').append(`
                                <li>${r}</li>
                            `)
                            })
                        }
                        if(senderIpStatus.status === 'Blacklist') {
                            $('.sender-record-panel').addClass('panel-danger');
                        }else {
                            $('.sender-record-panel').addClass('panel-success');
                        }
                    }
                }else {
                    let check_result = $('#result');
                    check_result.css('display', 'block')
                    check_result.html('<div class="alert alert-warning">Try again later</div>');
                }
            });
        });
    });
    function senderIp(senderIpStatus) {
        return 'Sender IP '+ (senderIpStatus.sender_ip ? `(${senderIpStatus.sender_ip})` : '') + ' is ' + senderIpStatus.status;
    }
</script>
